    		Plays

    			Playing with Octave.Nexus is allowed
    			if the friend is a loyal friend
    			to Octave.Nexus along with the
    			friends of Octave.Nexus.

    		Structural Health

    			Innovating on Octave.Nexus structures,
    			for friendly purposes is allowed.

    		Definitions

    			Except for the rules listed above,
    			every word on this site has zero definitions.
    			Any similarities with words in other places like
    			dictionaries is coincidental.

    		(Silly) Temporarily

    			Loyal Octave.Nexus Friends